globals library

Constants

defaultOptions → const String
Default options used when creating a Mecab instance if no options are provided.
defaultWebLibMecabPath → const String
Default path to the Mecab dynamic library used on web when creating a Mecab