MecabDartFfi class

Class that contains all Mecab FFi references

Constructors

MecabDartFfi()

Properties

destroyMecabFfi DestroyMecabFuncDart
latefinal
hashCode int
The hash code for this object.
no setterinherited
initMecabFfi InitMecabFuncDart
latefinal
mecabDartFfiHelper ↔ FfiHelper
latefinal
nativeAddFunc NativeAddFuncDart
latefinal
parseFfi ParseFuncDart
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({String? libmecabPath, FfiHelper? mecabFfiHelper}) Future<void>
Initializes the communication to ffi
initMecabString(String opt, String dicdir, String? libpath) → Pointer<Void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseString(Pointer<Void> tagger, String input) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited