MecabTransferableState class

Constructors

MecabTransferableState({required String mecabDictDirPath, String options = defaultOptions, String webLibMecabPath = defaultWebLibMecabPath})
MecabTransferableState.fromJson(Map<String, dynamic> json)
factory
MecabTransferableState.fromJsonString(String jsonString)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mecabDictDirPath String
final
options String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webLibMecabPath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toJsonString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited